@@ -58,7 +58,7 @@ navGraph <- function(data, graph = NULL, viz = NULL, settings = NULL) {
 					if(all(sapply(get(arg),function(x){is(x,arg_class)}))){
 						assign(paste(arg,"List", sep = ''),get(arg))	
 					}else{
-						stop(paste("[navGraph] elements in list ",arg," are not from class NG_",arg, sep = ''))
+						stop(paste("[navGraph] elements in list ",arg," are not from class ",arg_class, sep = ''))
 					}
 				} else {
 					stop(paste("[navGraph] argument ",arg," is neither a list of NG_", arg," objects nor a NG_", arg," object",sep = ''))
